==> haskell-th-env-0.1.0.3-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-env
version:              0.1.0.3
visibility:           public
id:                   th-env-0.1.0.3-E1luw76WVYrF98HlUkBOLe
key:                  th-env-0.1.0.3-E1luw76WVYrF98HlUkBOLe
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splice that expands to an environment variable

description:
    TH splice that expands to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  b05367f218461c22dc553b425201c317
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-env-0.1.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-env-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/th-env-0.1.0.3
hs-libraries:         HSth-env-0.1.0.3-E1luw76WVYrF98HlUkBOLe
depends:
    base-4.15.1.0 template-haskell-2.17.0.0
    th-compat-0.1.3-HpUe8cKrRTuL0Pq6ZrbcZY

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-env-0.1.0.3-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-env
version:              0.1.0.3
visibility:           public
id:                   th-env-0.1.0.3-9I5RBDayDUL3tvZKEGyD1m
key:                  th-env-0.1.0.3-9I5RBDayDUL3tvZKEGyD1m
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splice that expands to an environment variable

description:
    TH splice that expands to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  5f6efdd195b6d0acafee3e6b111deb65
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-env-0.1.0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-env-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/th-env-0.1.0.3
hs-libraries:         HSth-env-0.1.0.3-9I5RBDayDUL3tvZKEGyD1m
depends:
    base-4.15.1.0 template-haskell-2.17.0.0
    th-compat-0.1.3-7QQvRtLFJ80LeO4U9AzSn7

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
